@@ -25,11 +25,7 @@
 #'   fixed effects, see \url{https://github.com/lrberge/fixest/issues/6} and
 #'   \url{https://github.com/sgaure/lfe/issues/1#issuecomment-530646990})
 #'
-#' @examples
-#' 
-#' # feel free to ignore the following line—it allows {broom} to supply 
-#' # examples without requiring the model-supplying package to be installed.
-#' if (requireNamespace("fixest", quietly = TRUE)) {
+#' @examplesIf rlang::is_installed("fixest")
 #' 
 #' # load libraries for models and data
 #' library(fixest)
@@ -59,14 +55,14 @@
 #' tidy(gravity_summ, conf.int = TRUE)
 #' 
 #' # approach (1) is preferred.
-#' 
-#' }
 #'
 #' @export
 #' @family fixest tidiers
 #' @seealso [tidy()], [fixest::feglm()], [fixest::fenegbin()],
 #' [fixest::feNmlm()], [fixest::femlm()], [fixest::feols()], [fixest::fepois()]
 tidy.fixest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
+  check_ellipses("exponentiate", "tidy", "fixest", ...)
+  
   coeftable <- summary(x, ...)$coeftable
   ret <- as_tibble(coeftable, rownames = "term")
   colnames(ret) <- c("term", "estimate", "std.error", "statistic", "p.value")
