@@ -97,10 +97,15 @@ tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95,
   ret <- as_tibble(summary(x)$coefficients, rownames = "term")
   colnames(ret) <- c("term", "estimate", "std.error", "statistic", "p.value")
 
-  # summary(x)$coefficients misses rank deficient rows (i.e. coefs that
-  # summary.lm() sets to NA), catch them here and add them back
-  coefs <- tibble::enframe(stats::coef(x), name = "term", value = "estimate")
-  ret <- left_join(coefs, ret, by = c("term", "estimate"))
+  coefs <- stats::coef(x)
+
+  if (length(coefs) != nrow(ret)) {
+    # summary(x)$coefficients misses rank deficient rows (i.e. coefs that
+    # summary.lm() sets to NA), catch them here and add them back. This join is
+    # costly, so only do it when necessary.
+    coefs <- tibble::enframe(coefs, name = "term", value = "estimate")
+    ret <- left_join(coefs, ret, by = c("term", "estimate"))
+  }
 
   if (conf.int) {
     ci <- broom_confint_terms(x, level = conf.level)
